@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -24,7 +24,9 @@
 #include <QtDesigner/QExtensionFactory>
 #include <QtDesigner/QExtensionManager>
 #include <QtDesigner/QDesignerFormEditorInterface>
+#include <QtDesigner/QDesignerFormWindowInterface>
 #include <QtDesigner/QDesignerContainerExtension>
+#include <QtDesigner/QDesignerPropertySheetExtension>
 
 #include <QIcon>
 #include <QtPlugin>
@@ -41,27 +43,27 @@ MultiPageWidgetPlugin::MultiPageWidgetPlugin(QObject *parent)
 
 QString MultiPageWidgetPlugin::name() const
 {
-    return QString("MultiPageWidget");
+    return QLatin1String("MultiPageWidget");
 }
 
 QString MultiPageWidgetPlugin::group() const
 {
-    return QString("Display Widgets [Examples]");
+    return QLatin1String("Display Widgets [Examples]");
 }
 
 QString MultiPageWidgetPlugin::toolTip() const
 {
-    return "";
+    return QString();
 }
 
 QString MultiPageWidgetPlugin::whatsThis() const
 {
-    return "";
+    return QString();
 }
 
 QString MultiPageWidgetPlugin::includeFile() const
 {
-    return QString("multipagewidget.h");
+    return QLatin1String("multipagewidget.h");
 }
 
 QIcon MultiPageWidgetPlugin::icon() const
@@ -77,6 +79,10 @@ bool MultiPageWidgetPlugin::isContainer() const
 QWidget *MultiPageWidgetPlugin::createWidget(QWidget *parent)
 {
     MultiPageWidget *widget = new MultiPageWidget(parent);
+    connect(widget, SIGNAL(currentIndexChanged(int)),
+            this, SLOT(currentIndexChanged(int)));
+    connect(widget, SIGNAL(pageTitleChanged(const QString &)),
+            this, SLOT(pageTitleChanged(const QString &)));
     return widget;
 }
 
@@ -101,11 +107,41 @@ void MultiPageWidgetPlugin::initialize(QDesignerFormEditorInterface *formEditor)
 
 QString MultiPageWidgetPlugin::domXml() const
 {
-    return QString("\
+    return QLatin1String("\
     <widget class=\"MultiPageWidget\" name=\"multipagewidget\">\
-        <widget class=\"QWidget\" />\
+        <widget class=\"QWidget\" name=\"page\" />\
     </widget>\
     ");
 }
 
+void MultiPageWidgetPlugin::currentIndexChanged(int index)
+{
+    Q_UNUSED(index);
+    MultiPageWidget *widget = qobject_cast<MultiPageWidget*>(sender());
+    if (widget) {
+        QDesignerFormWindowInterface *form = QDesignerFormWindowInterface::findFormWindow(widget);
+        if (form)
+            form->emitSelectionChanged();
+    }
+}
+
+void MultiPageWidgetPlugin::pageTitleChanged(const QString &title)
+{
+    Q_UNUSED(title);
+    MultiPageWidget *widget = qobject_cast<MultiPageWidget*>(sender());
+    if (widget) {
+        QWidget *page = widget->widget(widget->currentIndex());
+        QDesignerFormWindowInterface *form;
+        form = QDesignerFormWindowInterface::findFormWindow(widget);
+        if (form) {
+            QDesignerFormEditorInterface *editor = form->core();
+            QExtensionManager *manager = editor->extensionManager();
+            QDesignerPropertySheetExtension *sheet;
+            sheet = qt_extension<QDesignerPropertySheetExtension*>(manager, page);
+            const int propertyIndex = sheet->indexOf(QLatin1String("windowTitle"));
+            sheet->setChanged(propertyIndex, true);
+        }
+    }
+}
+
 Q_EXPORT_PLUGIN2(containerextension, MultiPageWidgetPlugin)
