@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -36,9 +36,6 @@ public:
 
     QSize minimumSizeHint() const;
     QSize sizeHint() const;
-    int xRotation() const { return xRot; }
-    int yRotation() const { return yRot; }
-    int zRotation() const { return zRot; }
 
 public slots:
     void setXRotation(int angle);
