@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2005-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the example classes of the Qt Toolkit.
 **
@@ -21,23 +21,25 @@
 **
 ****************************************************************************/
 
-#include <QtGui>
 
 #include "interfaces.h"
 #include "paintarea.h"
 
-PaintArea::PaintArea(QWidget *parent)
-    : QWidget(parent)
+#include <QPainter>
+#include <QMouseEvent>
+
+PaintArea::PaintArea(QWidget *parent) :
+    QWidget(parent),
+    theImage(500, 400, QImage::Format_RGB32),
+    color(Qt::blue),
+    thickness(3),
+    brushInterface(0),
+    lastPos(-1, -1)
 {
     setAttribute(Qt::WA_StaticContents);
     setAttribute(Qt::WA_NoBackground);
 
-    theImage = QImage(500, 400, QImage::Format_RGB32);
     theImage.fill(qRgb(255, 255, 255));
-    color = Qt::blue;
-    thickness = 3;
-    brushInterface = 0;
-    lastPos = QPoint(-1, -1);
 }
 
 bool PaintArea::openImage(const QString &fileName)
@@ -102,7 +104,7 @@ void PaintArea::mousePressEvent(QMouseEvent *event)
             QPainter painter(&theImage);
             setupPainter(painter);
 
-            QRectF boundingRect = pendingPath.boundingRect();
+            const QRectF boundingRect = pendingPath.boundingRect();
             QLinearGradient gradient(boundingRect.topRight(),
                                      boundingRect.bottomLeft());
             gradient.setColorAt(0.0, QColor(color.red(), color.green(),
@@ -120,8 +122,8 @@ void PaintArea::mousePressEvent(QMouseEvent *event)
             if (brushInterface) {
                 QPainter painter(&theImage);
                 setupPainter(painter);
-                QRect rect = brushInterface->mousePress(brush, painter,
-                                                        event->pos());
+                const QRect rect = brushInterface->mousePress(brush, painter,
+                                                              event->pos());
                 update(rect);
             }
 
@@ -136,8 +138,8 @@ void PaintArea::mouseMoveEvent(QMouseEvent *event)
         if (brushInterface) {
             QPainter painter(&theImage);
             setupPainter(painter);
-            QRect rect = brushInterface->mouseMove(brush, painter, lastPos,
-                                                   event->pos());
+            const QRect rect = brushInterface->mouseMove(brush, painter, lastPos,
+                                                         event->pos());
             update(rect);
         }
 
